pub struct StrategyId(/* private fields */);Expand description
Represents a valid strategy ID.
Implementations
Sourceimpl StrategyId
impl StrategyId
Sourcepub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
pub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
Creates a new StrategyId instance.
Must be correctly formatted with two valid strings either side of a hyphen. It is expected a strategy ID is the class name of the strategy, with an order ID tag number separated by a hyphen.
Example: “EMACross-001”.
The reason for the numerical component of the ID is so that order and position IDs do not collide with those from another strategy within the node instance.
Errors
Returns an error if:
valueis not a valid ASCII string.valueis not “EXTERNAL” and does not contain a hyphen ‘-’ separator.- Either the name or tag part (before/after the hyphen) is empty.
pub fn external() -> Self
pub fn is_external(&self) -> bool